/* 
 * This file is part of the Echo Point Project.  This project is a collection
 * of Components that have extended the Echo Web Application Framework.
 *
 * EchoPoint is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * EchoPoint is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with Echo Point; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

//========================================================================================================
// Object maps
//========================================================================================================
var mapHSP = new Array();

//========================================================================================================
//
// The EchoTagger object
//
// A tagger follows its attached element mate by sitting constantly by its side 
// (like a tagger in Australian Rules football)
//
// The tagger can have an on image and off image that can be dynamically swapped
//
// alignment - ALIGN_LEFT, ALIGN_TOP, ALIGN_BOTTOM, ALIGN_RIGHT
//
//========================================================================================================
function EchoTagger(htmlId, htmlIdMate, alignment) {
	// members
	this.htmlId			= htmlId;
	this.htmlIdMate		= htmlIdMate;
	this.alignment  	= alignment || ALIGN_LEFT;
	this.e				= null;
	this.mateE			= null;
}

//---------------------------------------------
//---------------------------------------------
EchoTagger.prototype.onload = function() {
	this.e = getElementById(this.htmlId);
	this.mateE = getElementById(this.htmlIdMate);
	this.e.setVisible(true); 
	this.e.setStyle("position","absolute"); 
}

//---------------------------------------------
// toggle any select fields that may be 
// under the hsp and its tagger
//---------------------------------------------
EchoTagger.prototype.toggleSelectFields = function() {
	if (browser.isIE) {
		var ids = this.htmlId + '|' + this.htmlIdMate;
		epbe_hideSelectFieldsUnder(ids);
	}
}


//---------------------------------------------
// Called to update a taggers positiion
//---------------------------------------------
EchoTagger.prototype.tag = function() {

	var mateWidth = this.mateE.getWidth();
	var mateHeight = this.mateE.getHeight();
	var mateX = this.mateE.getX();
	var mateY = this.mateE.getY();

	var x 		= this.e.getX();
	var y 		= this.e.getY();
	var width 	= this.e.getWidth();
	var height 	= this.e.getHeight();
	
	if (this.alignment == ALIGN_LEFT) {
		this.e.setX(mateX - width);
		this.e.setY(mateY);
	}
	if (this.alignment == ALIGN_TOP) {
		this.e.setX(mateX);
		this.e.setY(mateY - height);
	}
	if (this.alignment == ALIGN_RIGHT) {
		this.e.setX(mateX + mateWidth);
		this.e.setY(mateY);
	}
	if (this.alignment == ALIGN_BOTTOM) {
		this.e.setX(mateX);
		this.e.setY(mateY + mateHeight);
	}
	// hide select fields in IE
	this.toggleSelectFields();
}

//========================================================================================================
//
// The EchoHSP object
//
// htmlId must be unqiue string that identifies the slider
// and is also the ID of the html element that will be slid!
//
// The EchoHSP starting position is determined by the isExpanded variable.
//
//========================================================================================================
function EchoHSP(htmlId, peerId, jump, x, y, alignment, isExpanded, imgId, imageExpanded, imageCollapsed, tagger) {

	// members
	this.htmlId			= htmlId;
	this.e				= null;
	this.peerId			= peerId;
	this.jump			= jump;
	this.alignment  	= alignment || ALIGN_LEFT;
	this.html			= "";
	this.zIndex			= 0;

	this.stepStart		= 5; 
	this.stepIncrease	= 1.5; 
	this.stepAmount		= this.stepStart;
	this.stepDirection  = +1;

	this.tagger 		= tagger||null;
	
	this.isExpanded 	= isExpanded;
	this.timer 			= null;
	
	this.imageId		= imgId;
	this.imageExpanded 	= imageExpanded;
	this.imageCollapsed = imageCollapsed;

	// add to internal map
	mapHSP[htmlId] 		= this;
}

//---------------------------------------------
//---------------------------------------------
EchoHSP.prototype.onload=function() {
	this.e = getElementById(this.htmlId);

	this.e.setStyle("position","absolute"); 

	var width = this.e.getWidth();
	var height = this.e.getHeight();
	var pageWidth = this.e.getPageWidth();
	var pageHeight = this.e.getPageHeight();

	var newX = this.e.getX();
	var newY = this.e.getY();

	if (this.alignment == ALIGN_LEFT) {
		if (this.isExpanded)
			newX = 0;
		else
			newX = (0 - width);
	}
	if (this.alignment == ALIGN_TOP) {
		if (this.isExpanded)
			newY = 0;
		else
			newY = (0 - height);
	}
	// if its right and bottom, then we make it take no space  to stop
	// it invoking the side scroll bars
	if (this.alignment == ALIGN_RIGHT) {
		if (this.isExpanded)
			newX = (pageWidth - width);
		else
			newX = (pageWidth);
	}
	if (this.alignment == ALIGN_BOTTOM) {
		if (this.isExpanded)
			newY = (pageHeight - height);
		else
			newY = (height);
	}
	this.e.setX(newX);
	this.e.setY(newY);
	
	this.e.setVisible(true);
	this.setImages();

	if (this.alignment == ALIGN_LEFT || this.alignment == ALIGN_TOP) {
		if (this.isExpanded)
			this.stepDirection  = +1;
		else
			this.stepDirection  = -1;
	} else {
		if (this.isExpanded)
			this.stepDirection  = -1;
		else
			this.stepDirection  = +1;
	}
	if (this.tagger != null) {
		this.tagger.tag();
	}

}


//---------------------------------------------
// Called to check whether the hsp has reached the end of a  path end, either the 
// start or the end.  Returns true if the hsp is at the end.  Does some
// adjusting to ensure it doesnt overstep the mark.
//---------------------------------------------
EchoHSP.prototype.isAtPathEdge = function() {
	var onEdge = false;
	
	var x 		= this.e.getX();
	var y 		= this.e.getY();
	var width 	= this.e.getWidth();
	var height 	= this.e.getHeight();
	var pageWidth 	= this.e.getPageWidth();
	var pageHeight 	= this.e.getPageHeight();

	if (this.alignment == ALIGN_LEFT) {
		if (this.isExpanded) {
			if (x >= 0) {
				this.e.setX(0);	
				onEdge = true;
			}
		} else {
			if (x <= 0 - width) {
				this.e.setX(0 - width);	
				onEdge = true;
			}
		}
	}
	if (this.alignment == ALIGN_TOP) {
		if (this.isExpanded) {
			if (y >= 0) {
				this.e.setY(0);	
				onEdge = true;
			}
		} else {
			if (y <= 0 - height) {
				this.e.setY(0 - height);	
				onEdge = true;
			}
		}
	}
	if (this.alignment == ALIGN_RIGHT) {
		if (this.isExpanded) {
			if (x <= pageWidth - width) {
				this.e.setX(pageWidth - width);	
				onEdge = true;
			}
		} else {
			if (x >= pageWidth) {
				this.e.setX(pageWidth);	
				onEdge = true;
			}
		}
	}
	if (this.alignment == ALIGN_BOTTOM) {
		if (this.isExpanded) {
			if (y <= pageHeight - height) {
				this.e.setY(pageHeight - height);	
				onEdge = true;
			}
		} else {
			if (y >= pageHeight) {
				this.e.setY(pageHeight);	
				onEdge = true;
			}
		}
	}
	return onEdge;
}


//---------------------------------------------
// Called to set the set the image that will be switched
// at the end of path.
//---------------------------------------------
EchoHSP.prototype.setImages = function() {
	var img = getElementById(this.imageId);
	if (img == null)
		return;

	if (this.isExpanded)
		img.htmlE.src = this.imageExpanded;
	else
		img.htmlE.src = this.imageCollapsed;
}

//---------------------------------------------
//  function that moves a slider object along a path
//  return true if the time should stop.
//---------------------------------------------
EchoHSP.prototype.stepAlong = function() {

	var atEdge = this.isAtPathEdge();
	if (atEdge) {
		if (this.tagger != null)
			this.tagger.tag();
		return true;
	}

	var width 	= this.e.getWidth();
	var height 	= this.e.getHeight();

	var xAmount = 0;
	var yAmount = 0;
	this.stepAmount =  this.stepAmount + this.stepIncrease;
	if (this.alignment == ALIGN_LEFT || this.alignment == ALIGN_RIGHT) {
		if (this.jump)
			this.stepAmount = width;
		xAmount = this.stepDirection * this.stepAmount;
	}
	if (this.alignment == ALIGN_TOP || this.alignment == ALIGN_BOTTOM) {
		if (this.jump)
			this.stepAmount = height;
		yAmount = this.stepDirection * this.stepAmount;
	}
	this.e.moveBy(xAmount,yAmount);
	
	// smooth out the movement by not over stepping the mark
	this.isAtPathEdge();
	
	if (this.tagger != null)
		this.tagger.tag();

	return false;
}

//---------------------------------------------
// if the slider is current at the end of its path
// and if it is, then it flips it and starts the 
// other way
//---------------------------------------------
EchoHSP.prototype.toggle = function() {

	this.isExpanded = ! this.isExpanded;

	this.setImages();
	this.saveState();

	this.stepAmount = this.stepStart;
	if (this.stepDirection > 0)
		this.stepDirection = -1;
	else
		this.stepDirection = +1;
		
	g_hsp_stepAlong(this.htmlId);
}


//---------------------------------------------
// Called to save the state of the slider
//---------------------------------------------
EchoHSP.prototype.saveState = function() {
	var stateStr = "";

	var content = getElementById(this.peerId);
	if (content)	
		stateStr += content.htmlE.scrollLeft + "," + content.htmlE.scrollTop;
	
	stateStr += "|";
	if (this.isExpanded)
		stateStr += "true";
	else
		stateStr += "false";

	// save our start if the save state function exists
	if (E_setParameter)
		E_setParameter(this.peerId,stateStr);
}

//---------------------------------------------
// Global function that moves a slider object along a path
// Its made global so it can call itself in a timer
//---------------------------------------------
function g_hsp_stepAlong(sliderObjName)
{
	var sliderObj = mapHSP[sliderObjName];
	if (sliderObj != null) {
		var halt = sliderObj.stepAlong();
		if (! halt) {
			sliderObj.timer=setTimeout('g_hsp_stepAlong("'+sliderObjName+'")',30);
		}
	}
}

//---------------------------------------------
// Global function to start the named slider moving
//---------------------------------------------
function g_hsp_toggle(sliderObjName) {
	var sliderObj = mapHSP[sliderObjName];
	if (sliderObj != null)
		sliderObj.toggle();
}

//---------------------------------------------
// Global function to for saving state
//---------------------------------------------
function g_hsp_saveState(sliderObjName) {
	var sliderObj = mapHSP[sliderObjName];
	if (sliderObj != null)
		sliderObj.saveState();
}


//---------------------------------------------
// Global function to for body onload
//---------------------------------------------
function g_hsp_onload(sliderObjName) 
{
	var sliderObj = mapHSP[sliderObjName];
	if (sliderObj != null) {
		if (sliderObj.tagger)
			sliderObj.tagger.onload();
		sliderObj.onload();
	}
}

