/* 
 * This file is part of the Echo Point Project.  This project is a collection
 * of Components that have extended the Echo Web Application Framework.
 *
 * EchoPoint is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * EchoPoint is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with Echo Point; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

/**************************************************************************

	This javascript is based on the code by Geir Landr (drop@destroydrop.com) 
	and hence is :

	Copyright (c) 2001 Geir Landr (drop@destroydrop.com)
	JavaScript Tree - www.destroydrop.com/hugi/javascript/tree/
	Version 0.96	

	This script can be used freely as long as all copyright messages are
	intact.
	
	The code was revised by Brad Baker (brad.baker@candle.com) in 2002.  The
	code was made into an JS object model.
	
**************************************************************************/

//---------------------------------------------
// Push and pop 
//---------------------------------------------
if(!Array.prototype.push) {
	function array_push() {
		for(var i=0;i<arguments.length;i++)
			this[this.length]=arguments[i];
		return this.length;
	}
	Array.prototype.push = array_push;
}

if(!Array.prototype.pop) {
	function array_pop(){
		lastElement = this[this.length-1];
		this.length = Math.max(this.length-1,0);
		return lastElement;
	}
	Array.prototype.pop = array_pop;
}

//---------------------------------------------
// A class of tree nodes
//---------------------------------------------
function EchoTreeNode(nodeId, text, url, showIcon, vTextAlignment, classA, classImg, openIconUrl, closedIconUrl) {
	this.nodeId 	= nodeId;
	this.text 		= text;
	this.url 		= url;
	this.parent 	= null;

	
	this.showIcon	= true;
	if (showIcon != null)
		this.showIcon	= showIcon;
		
	this.vTextAlignment	= 'top';
	if (vTextAlignment != null)
		this.vTextAlignment = vTextAlignment;
		
	this.classA 	= classA;
	this.classImg 	= classImg;
	
	this.openIconUrl = openIconUrl;
	this.closedIconUrl = closedIconUrl;
	
	this.children	= new Array();
}

//---------------------------------------------
//---------------------------------------------
EchoTreeNode.prototype.addNode = function(nodeChild) {
	nodeChild.parent = this;
	this.children[this.children.length] = nodeChild;
	return nodeChild;
}

//---------------------------------------------
//---------------------------------------------
EchoTreeNode.prototype.getChildCount = function() {
	return this.children.length;
}

//---------------------------------------------
//---------------------------------------------
EchoTreeNode.prototype.getChild = function(i) {
	if (i < this.children.length)
		return this.children[i];
	else
		return null;
}

//---------------------------------------------
// finds a node in the object tree by id
//---------------------------------------------
EchoTreeNode.prototype.findNode = function(nodeId) {
	if (this.nodeId == nodeId)
		return this;
		
	return this.findChildNode(this,nodeId);
}

//---------------------------------------------
// finds a node in the object tree by id
//---------------------------------------------
EchoTreeNode.prototype.findChildNode = function(parentNode, nodeId) {
	var cc = parentNode.getChildCount();
	for (var i = 0; i < cc; i++) {
		var node = parentNode.getChild(i);
		if (node.nodeId == nodeId)
			return node;
		
		if (node.getChildCount() > 0) {
			node = this.findChildNode(node,nodeId);
			if (node != null)
				return node;
		}
	}
	return null;
}

//---------------------------------------------
// A map of all tree on the page
//---------------------------------------------
var EchoTreeMap = new Array();

//---------------------------------------------
//
// The EchoTree object
//
// treeName must be unqiue string that identifies the tree
//
// rootNode must be the root TreeNode object
//
//---------------------------------------------
function EchoTree(treeName, enabled, rowHeight, rootNode ) {
	// members
	this.treeName		= treeName;
	this.enabled		= enabled;
	this.rowHeight		= rowHeight;
	this.rootNode		= null;
	if (rootNode != null)
		this.rootNode	= rootNode;

	this.showLines		= true;
	this.showRootHandle	= false;
	this.showRoot		= true;
		
	this.openNodes		= new Array();
	this.recursedNodes 	= new Array();
	this.icons			= new Array();
	this.classA			= "";
	this.classIMG		= "";
}

//---------------------------------------------
//---------------------------------------------
function imageHTML(image) {
	return ' src="' + image.src + '" width="' + image.width + '" height="' + image.height + '" align="top" border="0"  alt="" ';
}
//---------------------------------------------
// Create the tree. This should be called with a SCRIPT
// somewhere in the BODY of the document.  
//---------------------------------------------
EchoTree.prototype.create = function() {
	// add to the EchoTreeMap array so we can find outself
	EchoTreeMap[this.treeName] = this;

	if (this.rootNode != null) {
		var node  = this.rootNode;
		
		var isOpen = this.isNodeOpen(node);
		var anch = "a";
		if (! this.enabled)
			anch = "span";
			
		var tdPlain = '<td valign="top" nowrap>';
		if (this.rowHeight > 0)
			tdPlain = '<td valign="top" nowrap height="' + this.rowHeight + '">';

		var tdPlainText	= '<td valign="'+ node.vTextAlignment +'" nowrap>';
		if (this.rowHeight > 0)
			tdPlainText = '<td valign="'+ node.vTextAlignment +'" nowrap height="' + this.rowHeight + '">';

		if (this.showRoot) {
			document.write('<table border="0" cellspacing="0" cellpadding="0"><tr>');
			if (this.showRootHandle) {
				var uniqueNodeId = "" + this.treeName + "_" + node.nodeId;
			
				this.recursedNodes.push(1);
				document.write(tdPlain);
				document.write('<'+anch+' class="' + node.classA + '" href="javascript: g_eptree_oc(\''+ this.treeName+ '\',\'' + uniqueNodeId + '\', 0);"><img id="join' + uniqueNodeId + '" ');
				if (isOpen) 
					document.write(imageHTML(this.icons["minus"]));
				else 
					document.write(imageHTML(this.icons["plus"]));
				document.write(' align="top" alt="Open/Close node" /></'+anch+'>');
				document.write('</td>');
			}

			// draw the root node		
			if (node.showIcon) {
				var iconURL = '';
				if (isOpen) {
					if (node.openIconUrl == null)
						iconURL = this.icons["rootopen"].src;
					else
						iconURL = node.openIconUrl;
				} else {
					if (node.closedIconUrl == null)
						iconURL = this.icons["root"].src;
					else
						iconURL = node.closedIconUrl;
				}

				document.write(tdPlain);
				document.write('<'+anch+' class="' + node.classA + '" href="' + node.url + '"><img class="' + node.classImg + '" src="');
				document.write(iconURL);
				document.write('" align="top" alt="" /></'+anch+'>');
				document.write('</td>');
			}
			
			document.write(tdPlainText);
			document.write('<'+anch+' class="' + node.classA + '" href="' + node.url + '">' + node.text + '</'+anch+'>');
			document.write('</td></tr></table>');
		}
		var t = new Date().getTime();
		
		document.write('<div id="div' + uniqueNodeId + '"');
		if (!isOpen) 
			document.write(' style="display: none;"');
		document.write('>');
		this.drawNode(node, this.recursedNodes,true);
		document.write('</div>');
		
		t = new Date().getTime() - t;
		// - - - - - - - - - - - - - - - - - - - - - -  
		// uncomment here to perform timing debugging
		// window.status = "tree built in " + t + "ms";
	}
}

//----------------------------------------
// Recursively draws the tree starting at parentNode (a TreeNode object)
//----------------------------------------
EchoTree.prototype.drawNode = function(parentNode, recursedNodes) {

	var cc = parentNode.getChildCount();
	for (var i = 0; i < cc; i++) {
		
		var node = parentNode.getChild(i);
		
		var gcc = node.getChildCount();
		
		var lastSibling	= (i == (cc-1));
		var hasChildren	= (gcc > 0);
		var isOpen = this.isNodeOpen(node);
		var anch = "a";
		if (! this.enabled)
			anch = "span";		

		var classA = this.classA;
		var classImg = this.classImg;
		if (node.classA != null)
			classA = node.classA;
		if (node.classImg != null)
			classImg = node.classImg;
			
		var uniqueNodeId = "" + this.treeName + "_" + node.nodeId;
		var showLines = this.showLines;
		
		var image = this.icons["line"];

		var tdLine  = '<td valign="top" background="' + image.src + '" width="' + image.width + '" >';
		if (this.rowHeight > 0)
			tdLine  = '<td valign="top" background="' + image.src + '" height="' + this.rowHeight + ' width="' + image.width + '" >';

		var tdPlain	= '<td valign="top" nowrap>';
		if (this.rowHeight > 0)
			tdPlain = '<td valign="top" nowrap height="' + this.rowHeight + '">';

		var tdPlainText	= '<td valign="'+ node.vTextAlignment +'" nowrap>';
		if (this.rowHeight > 0)
			tdPlainText = '<td valign="'+ node.vTextAlignment +'" nowrap height="' + this.rowHeight + '">';
		
		var spacerCell = '<img ' + imageHTML(this.icons["empty"]) + ' />';

		var iconURL = '';
		if (hasChildren) {
			if (isOpen) {
				if (node.openIconUrl == null)
					iconURL = this.icons["folderopen"].src;
				else
					iconURL = node.openIconUrl;
			} else {
				if (node.closedIconUrl == null)
					iconURL = this.icons["folder"].src;
				else
					iconURL = node.closedIconUrl;
			}
		} else {
			if (node.openIconUrl == null)
				iconURL = this.icons["leaf"].src;
			else	
				iconURL = node.openIconUrl;
		}


		document.write('<table border="0" cellspacing="0" cellpadding="0"><tr>');
		// Write out line & empty icons
		for (var g=0; g<recursedNodes.length; g++) {
			if (recursedNodes[g] == 1  && showLines) {
				if (g == 0 && this.showRootHandle && this.showRoot)
					document.write(tdPlain + spacerCell + '</td>');
				else
					document.write(tdLine + spacerCell +'</td>');
			} else  {
				document.write(tdPlain + spacerCell + '</td>');
			}
		}
			

		// put in array line & empty icons
		if (lastSibling) 
			recursedNodes.push(0);
		else 
			recursedNodes.push(1);

		// Write out join icons
		if (hasChildren) {
			if (lastSibling && showLines) {
				document.write(tdPlain);
				document.write('<'+anch+' class="' + classA + '" href="javascript: g_eptree_oc(\'' + this.treeName + '\',\'' + uniqueNodeId + '\', 1);"><img id="join' + uniqueNodeId + '" ');
			 	if (isOpen) 
			 		document.write(imageHTML(this.icons["minusbottom"]));
				else 
					document.write(imageHTML(this.icons["plusbottom"]));
						
				document.write(' /></'+anch+'>');
			} else {
				if (showLines)
					document.write(tdLine);
				else
					document.write(tdPlain);
					
				document.write('<'+anch+' class="' + classA + '" href="javascript: g_eptree_oc(\'' + this.treeName+ '\',\'' + uniqueNodeId + '\', 0);"><img  id="join' + uniqueNodeId + '" ');
				if (isOpen) 
					document.write(imageHTML(this.icons["minus"]));
				else 
					document.write(imageHTML(this.icons["plus"]));
				document.write(' /></'+anch+'>');
			}
			document.write('</td>');
			
		} else {
			if (showLines) {
				if (lastSibling) {
					document.write(tdPlain);
					document.write('<img  ' + imageHTML(this.icons["joinbottom"]) + ' />');
				} else {
					document.write(tdLine);
					document.write('<img ' + imageHTML(this.icons["join"]) + ' />');
				}
			} else {
				document.write(tdPlain);
				document.write('<img ' + imageHTML(this.icons["joinnoline"]) + ' />');
			}
			document.write('</td>');
		}
		
		// Write out folder & leaf icons
		if (node.showIcon) {
			document.write(tdPlain);
			document.write('<'+anch+' class="' + classA + '" href="' + node.url + '">');
			document.write('<img  class="' + classImg + '" id="icon' + uniqueNodeId + '" src="' + iconURL + '" align="top" alt="" />');
			document.write('</'+anch+'>');
			document.write('</td>');
		}
		
		// Write out node name
		document.write(tdPlainText);
		//if (node.showIcon) {
			document.write('<'+anch+' class="' + classA + '" href="' + node.url + '" >');
		//}
		document.write(node.text);
		//if (node.showIcon) {
			document.write('</'+anch+'>');
		//}
		document.write('</td>');
		document.write('</tr></table>');
		// End link
			
		// If node has children write out divs and go deeper
		if (hasChildren) {
			document.write('<div id="div' + uniqueNodeId + '"');
			if (!isOpen) 
				document.write(' style="display: none;"');
			document.write('>');
			this.drawNode(node, recursedNodes);
			document.write('</div>');
		}
		
		// remove last line or empty icon 
		recursedNodes.pop();
	}
}


//----------------------------------------
// Creates an array of nodes that will be open
// when the tree is draw.  This can called
// before "create" is called.
//----------------------------------------
EchoTree.prototype.setNodeOpen = function(node) {
	if (node != null) {
		if (! this.isNodeOpen(node))
			this.openNodes.push(node.nodeId);
		if (node.parent != null)
			this.setNodeOpen(node.parent);
	} 
}

//----------------------------------------
// Checks if a node is open
//----------------------------------------
EchoTree.prototype.isNodeOpen = function(node) {
	for (var i = 0; i < this.openNodes.length; i++) {
		if (this.openNodes[i] == node.nodeId)
			return true;
	}
	return false;
}

//----------------------------------------
// Opens a node by placing it in the open
// nodes array.
//----------------------------------------
EchoTree.prototype.openNode = function(nodeId) {
	// close its parent
	var node = this.rootNode.findNode(nodeId);
	if (node == null)
		return;

	if (! this.isNodeOpen(node))
		this.openNodes[this.openNodes.length] = nodeId;

	if (node.parent != null) {
		this.openNode(node.parent.nodeId);
	}
}


//----------------------------------------
// Closes a node (by removing it from 
// the open nodes array along with any children).
//----------------------------------------
EchoTree.prototype.closeNode = function(nodeId) {
	var node = this.rootNode.findNode(nodeId);
	if (node == null)
		return;

	for (var i = 0; i < this.openNodes.length; i++) {
		if (this.openNodes[i] == nodeId) {
			this.openNodes[i] = null;
		}
	}
}


//----------------------------------------
// Returns a string that represents the nodeId's of visible nodes
//----------------------------------------
EchoTree.prototype.getVisibleNodes = function() {
	var visibleNodesStr = "";
	if (this.isNodeOpen(this.rootNode)) {
		visibleNodesStr += this.rootNode.nodeId;
		//
		// the node text is captured only for debugging
		//visibleNodesStr += "=" + this.rootNode.text;
		visibleNodesStr += this.getVisibleChildNodes(this.rootNode);
	}
	return visibleNodesStr;
}

//----------------------------------------
// see above
//----------------------------------------
EchoTree.prototype.getVisibleChildNodes = function(parentNode) {
	var visibleNodesStr = "";
	var cc = parentNode.getChildCount();
	for (var i = 0; i < cc; i++) {

		var node = parentNode.getChild(i);
		
		var isOpen = this.isNodeOpen(node);
		var hasChildren	= node.getChildCount() > 0;

		visibleNodesStr += '|' + node.nodeId;
		// If node has children go deeper
		if (hasChildren && isOpen) {
			visibleNodesStr += this.getVisibleChildNodes(node);
		}
	}
	return visibleNodesStr;
}

//---------------------------------------------
//
// Sets an icon image to a specified source.  The icon 
// names are as follows :
//
// "plus"			- the expanding + for normal nodes with children
// "plusbottom"		- the expanding + for the last node of a parent node
// "minus"			- the contracting - for normal nodes with children
// "minusbottom"	- the contracting - for the last node of a parent node
// "folder"			- a folder icon for closed nodes with children
// "folderopen"		- a folder icon for opened nodes with children
// "join"			- a joiner icon for for normal nodes
// "joinbottom"		- a joiner icon for the last node of a parent node
// "joinnoline"		- a joiner icon for nodes when lines are not to be drawn
// "leaf"			- a leaf icon for nodes with no children
// "line"			- a line icon between nodes
// "empty"			- a empty icon between nodes
// "root"			- a root icon 
//
//---------------------------------------------
EchoTree.prototype.setIcon = function(imageName,imageSrc,width,height) {
	if (width != null && height != null)
		this.icons[imageName] = new Image(width,height);
	else
		this.icons[imageName] = new Image();
	this.icons[imageName].src = imageSrc;
}

//---------------------------------------------
// Sets the class style to use for anchors and 
// img tags
//---------------------------------------------
EchoTree.prototype.setStyles = function(classA, classImg) {
	this.classA = classA;
	this.classImg = classImg;
}


//----------------------------------------
//----------------------------------------
EchoTree.prototype.dumpOpenNodes = function() {
	var s = "";
	for (var i = 0; i < this.openNodes.length; i++) {
		if (this.openNodes[i] != null)
			s = s + "|" + this.openNodes[i];
	}
	return s;		
}


//----------------------------------------
// Opens or closes a node
//----------------------------------------
function g_eptree_oc(treeName, node, bottom) {
	var echoTree = EchoTreeMap[treeName];
	if (echoTree.enabled == false)
		return;
		
	var theDiv = getElementById("div" + node);
	var theJoin	= getElementById("join" + node);
	var theIcon = getElementById("icon" + node);
	var nodeId = node.substring(node.lastIndexOf('_')+1);
	var node = echoTree.rootNode.findNode(nodeId);

	if (theDiv.htmlE.style.display == 'none') {
		if (bottom==1) 
			theJoin.htmlE.src = echoTree.icons["minusbottom"].src;
		else 
			theJoin.htmlE.src = echoTree.icons["minus"].src;
		
		if (theIcon != null) {
			var iconUrl = echoTree.icons["folderopen"].src;	
			if (node != null && node.openIconUrl != null)
				iconUrl = node.openIconUrl;
			theIcon.htmlE.src = iconUrl;
		}
		theDiv.htmlE.style.display = '';
		echoTree.openNode(nodeId);
	} else {
		if (bottom==1) 
			theJoin.htmlE.src = echoTree.icons["plusbottom"].src;
		else 
			theJoin.htmlE.src = echoTree.icons["plus"].src;
			
		if (theIcon != null) {
			var iconUrl = echoTree.icons["folderopen"].src;	
			if (node != null && node.closedIconUrl != null)
				iconUrl = node.closedIconUrl;
			theIcon.htmlE.src = iconUrl;
		}
		theDiv.htmlE.style.display = 'none';
		echoTree.closeNode(nodeId);
	}

	var visibleNodes = echoTree.getVisibleNodes();
	if (E_setParameter)
		E_setParameter(echoTree.treeName,visibleNodes);
}

