/* JobServer Oracle schema */

/*
  Apply this sql script to your database to create the JobServer
  database. Make sure the database user that applies this script
  has adequate privileges.

  If the database user, to be used by the JobServer applications,
  is a name other than "jsuser", replace in this script all occurrences
  of "jsuser" with whatever database username you chose instead. It is
  recommended to create a user "jsuser" whom will own the tables
  and be used by the JobServer applcations to access that database.
  But any other valid database user can be used instead.

*/


CREATE TABLE jsuser.js_dbversion
(
 stTag varchar2(64),
 dtEntered date
 );

CREATE TABLE jsuser.js_serial_tbl
(
 type number(5) not null,
 maxid number(20) not null
 );

CREATE TABLE jsuser.js_lock_tbl
(
 type number(5) not null,
 val number(5) not null
);

/* SOAFaces jar expander */
INSERT INTO jsuser.js_lock_tbl VALUES (1, 1);
/* JS Instance mutex */
INSERT INTO jsuser.js_lock_tbl VALUES (2, 2);
/* aux 1 */
INSERT INTO jsuser.js_lock_tbl VALUES (3, 3);
/* aux 2 */
INSERT INTO jsuser.js_lock_tbl VALUES (4, 4);
/* aux 3 */
INSERT INTO jsuser.js_lock_tbl VALUES (5, 5); 

CREATE TABLE jsuser.js_syscheck
(
 stHostname varchar2(64) not null,
 dtTime number(20)
);

INSERT INTO jsuser.js_syscheck (sthostname) VALUES ('empty');

CREATE TABLE jsuser.js_systemprops
(
 stMailServer varchar2(64),
 stReplyToAlertAddress varchar2(64),
 stSysAlertAddresses varchar2(255),
 stJobAlertAddresses varchar2(255),
 stTimeZone varchar2(128) DEFAULT '',
 bMuleServerEnabled number(1) DEFAULT 0, /* 1 true, 0 false */
 bSchedPerPartition number(1) DEFAULT 0,
 bSchedSharedDB number(1) DEFAULT 1,
 iSchedDefaultThreadSize number(3) DEFAULT 2,
 stCurrentSchedServer varchar2(64) null,
 stMailServerUser varchar2(32),
 stMailServerPass varchar2(128),
 iMailPort number(7) DEFAULT -1, /* -1 use default */
 tMailSecurity number(1) DEFAULT 0 /* 0 none, 1 SSL, 2 TLS */
 );

INSERT INTO jsuser.js_systemprops VALUES (NULL,NULL,NULL,NULL,'',0,0,0,2,NULL,NULL,NULL,-1,0);

CREATE TABLE jsuser.js_systeminfo
(
 stInstanceDisplayName varchar2(64),
 stSystemSyncTag char(32),
 dtSystemSyncTagCreate date,
 dtSystemSyncTagUpdate date
 );

INSERT INTO jsuser.js_systeminfo VALUES ('give_me_a_name',NULL,SYSTIMESTAMP,SYSTIMESTAMP);

INSERT INTO jsuser.js_serial_tbl (type,maxid) VALUES (1, 0);
INSERT INTO jsuser.js_serial_tbl (type,maxid) VALUES (2, 0);
INSERT INTO jsuser.js_serial_tbl (type,maxid) VALUES (3, 0);
INSERT INTO jsuser.js_serial_tbl (type,maxid) VALUES (4, 0);
INSERT INTO jsuser.js_serial_tbl (type,maxid) VALUES (5, 0);
INSERT INTO jsuser.js_serial_tbl (type,maxid) VALUES (6, 1);
INSERT INTO jsuser.js_serial_tbl (type,maxid) VALUES (7, 1);
/* node id */
INSERT INTO jsuser.js_serial_tbl (type,maxid) VALUES (8, 0);
/* node run id */
INSERT INTO jsuser.js_serial_tbl (type,maxid) VALUES (9, 0); 

CREATE TABLE jsuser.js_jobdate
(
 idJob number(20) not null ,  /* seq ref */
 idRec number(20) not null , /* sequence */
 dtSched date,
 dtExpire date,      /* expire date past scheduleddate */
 dtEffPrior date,
 dtEff date,
 tRecType number(1) DEFAULT 1,  /* 1 - custom, 2 - ex days, 3 - inc days, 4 - ex range, 5 - ex time range */
 tDaysWeek number(7) DEFAULT 1,

 CONSTRAINT js_jobdate_pk PRIMARY KEY (idJob, idRec)
 );

CREATE TABLE jsuser.js_res_grp
(
 id number(20) not null, /* seq type 6 */
 stname varchar2(32) not null,
 isize number(7),
 ifreeze number(2) DEFAULT 1, /*  2 frozen, 1 thaw */
 ifreezelocal number(2) DEFAULT 1, /*  2 frozen, 1 thaw */
 ischedsize number(7) DEFAULT 2,
 ilocalschedsize number(7) DEFAULT 3,
 bUseRemoteAgents number(2) DEFAULT 2, /* 2 no, 1 yes */
 ischedenabled number(2) DEFAULT 1, /* 2 no, 1 yes */
 stJobAlertAddresses varchar2(255),
 tExtJvmMode number(2) DEFAULT 0, /* 0 Ext/Local (default local), 2 local only, 3 Ext only */
 iExtJvmMaxMem number(10) DEFAULT -1, /* -1 means do not set max jvm */
 stOtherJvmOptions varchar2(128) DEFAULT '',

 CONSTRAINT js_res_grp_pk PRIMARY KEY (id),
 CONSTRAINT js_res_grp_unq UNIQUE (stname)
 );

INSERT INTO jsuser.js_res_grp (id,stname,isize,ifreeze,ischedsize,ischedenabled,stjobalertaddresses,textjvmmode,iextjvmmaxmem,stotherjvmoptions)
                VALUES (1,'RootPartition',3,1,2,1,NULL,0,-1,'');

CREATE TABLE jsuser.js_db_res
(
 id number(20), /* should be a seq for rights enforcement */
 stname varchar2(20),
 sturl varchar2(255),
 stuser varchar2(20),
 stpass varchar2(20)
 );

CREATE TABLE jsuser.js_job
(
 idJob number(20) not null, /* sequence */
 stName varchar2(128) not null,
 stDescr varchar2(255),
 tSched number(20) DEFAULT 1,
 tStatus number(3) DEFAULT 2, /* 1 pause, 2 stop, 3 active */
 iExpireval number(20) DEFAULT -1, /* seconds past next rundate to expire this, -1 none, -2 for custom interval */
 dtStart date not null,
 dtNext date,
 dtLast date,
 iresourcegrp number(20) DEFAULT 1,
 idJobGroup number(20) DEFAULT 1,
 iChoose number(4) DEFAULT 1,
 iField0 number(20) DEFAULT -1,
 iField1 number(20) DEFAULT -1,
 iField2 number(20) DEFAULT -1,
 iField3 number(20) DEFAULT -1,
 dtEndBy date,
 iEffOffset number(20) DEFAULT 0, /* -1 means use custom dates field */
 iPriorEffOffset number(20) DEFAULT 0,
 iSchedMax number(20) DEFAULT -1,
 iSchedCounter number(20) DEFAULT 0,
 iSchedTotal number(20) DEFAULT 0,
 tRelative number(1) DEFAULT 1,
 tSkip number(1) DEFAULT 2,
 stdepend1 varchar2(64),
 stdepend2 varchar2(64),
 stdepend3 varchar2(64),
 stAlertAddresses varchar2(255),
 ipriority number(4),
 iworktype number(4) DEFAULT 1,
 ijobschedenabled number(4) DEFAULT 2,
 ijobrunmode number(4) DEFAULT 1,
 iapplaunchenabled number(4) DEFAULT 1,
 tOneAtTime number(1) DEFAULT 1,
 tExpireLogging number(1) DEFAULT 2,
 tExtJvmMode number(2) DEFAULT 1, /* 1 local, 2 Ext */
 iExtJvmMaxMem number(6) DEFAULT -1, /* -1 means do not specify max jvm */
 tExtJvmUseMuleLoader number(2) DEFAULT 1,
 tExtJvmUseContListener number(2) DEFAULT 1,
 tRetired number(2) DEFAULT 1,
 tRetryConfig number(2) DEFAULT 0, /* 0 no retry, 1 retry from last incomplete tasklet, 2 retry from start - v2.4.0 */
 iRetryLimit number(2) DEFAULT 0, /* 0 or less means unlimited - v2.4.0 */

 CONSTRAINT js_job_pk PRIMARY KEY (idJob)
 );

CREATE TABLE jsuser.js_jobbean
(
 id number(20) not null, /* sequence */
 idJob number(20) not null,  /* seq ref */
 stType varchar2(255),
 stJarname varchar2(255),
 stName varchar2(128), /* must be unique in job */
 stDescr varchar2(255),
 iBeanseq number(5) not null,
 tErrordep number(2) DEFAULT 2, /* 1 means job stops execution if OperationException, 2 job continutes if OperationExeption */
 tInputtype number(5) DEFAULT 1, /* 1 none, 2 before only, 3 all tasks, 4 custom */
 tBlob number(1) DEFAULT 1, /* 1 means blob present, 2 otherwise */
 bEnabled number(3) not null, /* 1 is active, 2 is inactive */
 tIOSave number(1) DEFAULT 1, /* 1 no saving, 2 save output only, 3 save input only, 4 save both */
 stEndPoints varchar2(255) DEFAULT '',
 stHtmlInject varchar2(255) DEFAULT '',
 bUseMuleApi number(2) DEFAULT 2, /* 1 is active, 2 is inactive */
 tThreadJoin number(2) DEFAULT 0, /* 0 use sys default, 1 yes join, 2 no join - v2.4.0 */

 CONSTRAINT js_jobbean_pk PRIMARY KEY (idjob, id)
 );

/* list of prior beans that should be referenced */
/* Every operation will have one record for every operation before it */
CREATE TABLE jsuser.js_op_bean_link
(
 idwb number(20) not null,
 idopin number(20) not null,  /* internal id */
 idopout number(20) not null, /*  multiple relationships to internal id */
 dep number(2) DEFAULT 2      /* if 1 ALL props are read from output bean and mapped with */
 );

CREATE TABLE jsuser.js_op_prop_link
(
 idwb number(20) not null,
 idopin number(20) not null, /* internal id */
 idopout number(20) not null, /*  multiple relationships to internal id */
 inname varchar2(255) not null,
 outname varchar2(255) not null
 );

CREATE TABLE jsuser.js_persqueue
(
 idrun number(20) not null, /* sequence  seq_wbstatus */
 iBlob number(1) DEFAULT 1, /* 1 means blob present, 2 otherwise */
 idjob number(20),
 stname varchar2(128),
 iresgrp number(20),
 ipriority number(4),
 iorigpriority number(4),
 iorder number(20) not null,
 dtenterq date,
 ifreeze number(2) DEFAULT 1, /*  2 frozen, 1 thaw */

 CONSTRAINT js_persqueue_pk PRIMARY KEY (idRun)
 );

CREATE TABLE jsuser.js_opstatus
(
 idrun number(20) not null,
 idjob number(20) not null,
 idtask number(20) not null,
 sttaskname varchar2(128) not null,
 dtenter date not null,
 dtexit date,
 iexitstatus number(2) DEFAULT 0, /* 0 running, 1 completed, 2 failure, 3 disabled, 4 never finished - cleaned up, 5 running pending approval */
 iExitReason number(2) DEFAULT 0, /* 0 NA, 1 normal, 2 exit user, 3 failure/continue, 4 failure/exit, 5 internal error exit */
 ierror number(2) DEFAULT 0, /* updated when op finished running 1 means errors exist */
 iwarn number(2) DEFAULT 0, /* updated when op finishes running 1 means warnings exist */
 stfailmsg varchar2(255),
 stVersion varchar2(255) not null,
 tIOSave number(1) DEFAULT 1, /* 1 no saving, 2 save output only, 3 save input only, 4 save both */
 iUserExitValue number(20),
 stUserExitMsg varchar2(255) DEFAULT '',
 idNode number(20) DEFAULT -3, /* -1 is primary, -2 secondary, -3 not assigned yet */
 iBeanseq number(5) DEFAULT -1,
 tRetryJobConfig number(2) DEFAULT 0, /* 0 not job retry, 1 retry from last incomplete tasklet, 2 retry from start - v2.4.0 */
 tRetryTasklet number(2) DEFAULT 0, /* 0 not retry of any kind, 1 copied over from parent, 2 retried at least once - v2.4.0 */

 CONSTRAINT js_opstatus_pk PRIMARY KEY (idRun, idJob, idTask)
 );

CREATE TABLE jsuser.js_wbstatus
(
 idrun number(20) not null, /* sequence  seq_wbstatus */
 idjob number(20) not null,
 stuser varchar2(32),
 dtrun number(20) not null,
 dtsched number(20),
 dtenterq number(20),
 dtenterwp number(20),
 dtexitwp number(20),
 istatus number(3) not null, /* 1=scheduled, 2=forced, 3=extreme force, 4=scheduled but expired */
 iresgrp number(20),  /* -1 if run using OneTimeJP */
 iexitstatus number(2) DEFAULT 0, /* 0 queued, 1 running, 2 completed, 3 failure in at least one task, 4 wb never finished - cleaned up, 5 running pending approval */
 iExitReason number(2) DEFAULT 0, /* 0 NA, 1 normal, 2 exit user, 3 failure/exit, 4 internal error exit */
 ierror number(2) DEFAULT 0, /* updated when any op finishes running 1 means errors exist */
 iwarn number(2) DEFAULT 0, /* updated when any op finishes running 1 means warnings exist */
 stfailmsg varchar2(255),
 iUserExitValue number(20),
 stUserExitMsg varchar2(255) DEFAULT '',
 tJvmMode number(2) DEFAULT 0, /* 0 local/shared, 1 separate JVM, 2 isolates */
 idNode number(20) DEFAULT -3, /* -1 is primary, -2 secondary, -3 not assigned yet */
 stNodeName varchar2(64),
 dtKillRequest number(20),
 stKillUser varchar2(64),
 tRetryConfig number(2) DEFAULT 0, /* Retry config value when job was orig first run - 0 not job retry, 1 retry from last incomplete tasklet, 2 retry from start - v2.4.0 */
 idRunOrig number(20) DEFAULT -1, /* if positive means a retry run  - v2.4.0 */

 CONSTRAINT js_wbstatus_pk PRIMARY KEY (idRun)
 );

CREATE TABLE jsuser.js_engstatus
(
 idrun number(20) not null,
 dtstart date not null,
 dtschedstart date,
 dtexit date,
 iexitstatus number(2) DEFAULT 0, /* 0 running, 1 gracefully shutdown, 2 immediate shutdown, 3 crashed and cleanedup */
 ijprocstate number(1) DEFAULT 1,  /* 1 jp enabled, jp disabled 0 */
 ijschedstate number(1) DEFAULT 1, /* 1 jsched enabled, jsched disabled 0 */
 sthostname varchar2(64),
 imanualstart number(1) DEFAULT 1,  /* 1 manual, 0 auto/ws start */

  CONSTRAINT js_engstatus_pk PRIMARY KEY (idRun)
 );

CREATE TABLE jsuser.js_runwbstate
(
 idrun number(20) not null,
 idwb number(20) not null,
 sttaskname varchar2(128),
 idop number(20) not null,
 stdescrip varchar2(255),
 dtrequest date not null,
 dtexpire date, /* null means it never expires */
 stusername varchar2(32),
 dtreply date,
 istatus number(2) DEFAULT 0 /* 0 pending, 1 approved, 2 rejected by approver, 3 terminiated by user, 4 expired and system cleanup */
 );

/* record must be deleted on approval and cleanup */
CREATE TABLE jsuser.js_runwbdata
(
 idrun number(20) not null
 /* data blob not null */
 );

CREATE TABLE jsuser.js_juser
(
 stUserName varchar2(32) not null,
 stPassword varchar2(32) not null,
 bEnabled number(1) DEFAULT 1,  /* 1 enabled, 2 disabled */
 stLastName varchar2(32),
 stFirstName varchar2(32),
 stEmail varchar2(64),
 stPhone varchar2(16),
 bAllPartition number(1) DEFAULT 2, /* 1 yes, 2 no */
 bAllJobGroup number(1) DEFAULT 2,   /* 1 yes, 2 no */

 CONSTRAINT js_juser_pk PRIMARY KEY (stUserName)
 );

INSERT INTO jsuser.js_juser (stUserName, stPassword,benabled,stlastname,stfirstname,stemail,stphone,ballpartition,balljobgroup)
              VALUES ('admin', '9a2a96d4e7907c6cd09c7f8cbfe013b9',1,NULL,NULL,NULL,NULL,2,2);

CREATE TABLE jsuser.js_jobgroup
(
 id number(10) not null,
 stName varchar2(32) not null,
 stDesc varchar2(255),
 stJobAlertAddresses varchar2(255),

  CONSTRAINT js_jobgroup_pk PRIMARY KEY (id),
  CONSTRAINT js_jobgroup_unq UNIQUE (stname)
 );

INSERT INTO jsuser.js_jobgroup (id, stname, stdesc, stjobalertaddresses) VALUES (1, 'DEFAULT', 'Default Group',NULL);

CREATE TABLE jsuser.js_user_region
(
 stUsername varchar2(32) not null,
 stRegionName varchar2(32) not null,

 CONSTRAINT js_user_region_pk PRIMARY KEY (stUsername, stRegionName)
 );

CREATE TABLE jsuser.js_user_jobgroup
(
 stUsername varchar2(32) not null,
 idJobGroup number(20) not null,

 CONSTRAINT js_user_jobgroup_pk PRIMARY KEY (stUsername, idJobGroup)
 );

CREATE TABLE jsuser.js_user_partition
(
 stUsername varchar2(32) not null,
 idPartition number(20) not null,

 CONSTRAINT js_user_partition_pk PRIMARY KEY (stUsername, idPartition)
 );

CREATE TABLE jsuser.js_depend
(
 stname varchar2(64) not null,
 stDescr varchar2(255),
 stType varchar2(255),
 bsatisified number(1) DEFAULT 2, /* 1 yes, 2 no */
 dtstart date,
 dtend date,

 CONSTRAINT js_depend_pk PRIMARY KEY (stname)
 );

CREATE TABLE jsuser.js_taudit
(
 stusername varchar2(32) not null,
 dtAction date not null,
 tAction number(10) not null,
 stKey varchar2(128),
 stDetail varchar2(255)
 );

CREATE TABLE jsuser.js_node_partition_rel
(
 idNode number(20) not null,
 idPartition number(20) not null,
 iSize number(7) DEFAULT 0,
 bActive number(2) DEFAULT 1, /* 1 yes, 2 no */

 CONSTRAINT js_node_partition_rel_pk PRIMARY KEY (idNode, idPartition)
);

CREATE TABLE jsuser.js_node
(
 idnode number(20) not null,
 stname varchar2(64) not null,
 sthostname varchar2(128) not null,
 iport number(7) not null,
 bactive number(2) DEFAULT 1, /* 1 yes, 2 no */
 iJvmMaxMem number(7) DEFAULT -1, /* -1 means do not set max jvm */
 stOtherJvmOptions varchar2(128) DEFAULT '',
 bNodeOnly number(2) DEFAULT 1, /* 1 yes, 2 no */
 bDeleteFlag number(2) DEFAULT 2, /* 1 yes, 2 no */
 dtTime date, /* heartbeat */
 bCleaned number(2) DEFAULT 2, /* 1 yes, 2 no for heartbeat */

 CONSTRAINT js_node_pk PRIMARY KEY (idNode),
 CONSTRAINT js_node_unq UNIQUE (sthostname)
);

CREATE TABLE jsuser.js_nodestatus
(
 idrun number(20) not null,
 idnode number(20) not null,
 stname varchar2(64) not null,
 sthostname varchar2(128) not null,
 dtstart date not null,
 dtexit date,
 iexitstatus number(2) DEFAULT 0, /* 0 running, 1 gracefully shutdown, 2 immediate shutdown, 3 crashed and cleanedup */
 imanualstart number(2) DEFAULT 1, /* 1 manual, 0 auto/ws start */

 CONSTRAINT js_nodestatus_pk PRIMARY KEY (idrun)
 );

/* CREATE INDEX jsuser.js_jobdate_idx ON jsuser.js_jobdate (idjob); */
CREATE INDEX jsuser.js_job_name_idx ON jsuser.js_job (stname,idjob);
CREATE INDEX jsuser.js_op_bean_link_idx ON jsuser.js_op_bean_link (idwb);
CREATE INDEX jsuser.js_op_prop_link_idx ON jsuser.js_op_prop_link (idwb);
CREATE INDEX jsuser.js_wbstatus_iexit_idx ON jsuser.js_wbstatus (iexitstatus,idjob);
CREATE INDEX jsuser.js_wbstatus_date_idx ON jsuser.js_wbstatus (dtrun,idjob);
/* v2.4.0 */
CREATE INDEX jsuser.js_wbstatus_orig_idx ON jsuser.js_wbstatus (idrunorig);
CREATE INDEX jsuser.js_wbstatus_res_date_idx ON jsuser.js_wbstatus (iresgrp,dtrun,idjob);
CREATE INDEX jsuser.js_engstatus_idx ON jsuser.js_engstatus (dtStart);
CREATE INDEX jsuser.js_taudit_idx ON jsuser.js_taudit (dtAction);
CREATE INDEX jsuser.js_nodestatus_idx ON jsuser.js_nodestatus (dtStart);


/*** Privileges granted to jsuser ***/
/*
GRANT SELECT ON jsuser.js_dbversion TO jsuser;
GRANT UPDATE ON jsuser.js_dbversion TO jsuser;
GRANT INSERT ON jsuser.js_dbversion TO jsuser;
GRANT DELETE ON jsuser.js_dbversion TO jsuser;

GRANT SELECT ON jsuser.js_serial_tbl TO jsuser;
GRANT UPDATE ON jsuser.js_serial_tbl TO jsuser;
GRANT INSERT ON jsuser.js_serial_tbl TO jsuser;
GRANT DELETE ON jsuser.js_serial_tbl TO jsuser;

GRANT SELECT ON jsuser.js_systemprops TO jsuser;
GRANT UPDATE ON jsuser.js_systemprops TO jsuser;
GRANT INSERT ON jsuser.js_systemprops TO jsuser;
GRANT DELETE ON jsuser.js_systemprops TO jsuser;

GRANT SELECT ON jsuser.js_jobdate TO jsuser;
GRANT UPDATE ON jsuser.js_jobdate TO jsuser;
GRANT INSERT ON jsuser.js_jobdate TO jsuser;
GRANT DELETE ON jsuser.js_jobdate TO jsuser;

GRANT SELECT ON jsuser.js_res_grp TO jsuser;
GRANT UPDATE ON jsuser.js_res_grp TO jsuser;
GRANT INSERT ON jsuser.js_res_grp TO jsuser;
GRANT DELETE ON jsuser.js_res_grp TO jsuser;

GRANT SELECT ON jsuser.js_db_res TO jsuser;
GRANT UPDATE ON jsuser.js_db_res TO jsuser;
GRANT INSERT ON jsuser.js_db_res TO jsuser;
GRANT DELETE ON jsuser.js_db_res TO jsuser;

GRANT SELECT ON jsuser.js_job TO jsuser;
GRANT UPDATE ON jsuser.js_job TO jsuser;
GRANT INSERT ON jsuser.js_job TO jsuser;
GRANT DELETE ON jsuser.js_job TO jsuser;

GRANT SELECT ON jsuser.js_jobbean TO jsuser;
GRANT UPDATE ON jsuser.js_jobbean TO jsuser;
GRANT INSERT ON jsuser.js_jobbean TO jsuser;
GRANT DELETE ON jsuser.js_jobbean TO jsuser;

GRANT SELECT ON jsuser.js_op_bean_link TO jsuser;
GRANT UPDATE ON jsuser.js_op_bean_link TO jsuser;
GRANT INSERT ON jsuser.js_op_bean_link TO jsuser;
GRANT DELETE ON jsuser.js_op_bean_link TO jsuser;

GRANT SELECT ON jsuser.js_op_prop_link TO jsuser;
GRANT UPDATE ON jsuser.js_op_prop_link TO jsuser;
GRANT INSERT ON jsuser.js_op_prop_link TO jsuser;
GRANT DELETE ON jsuser.js_op_prop_link TO jsuser;

GRANT SELECT ON jsuser.js_persqueue TO jsuser;
GRANT UPDATE ON jsuser.js_persqueue TO jsuser;
GRANT INSERT ON jsuser.js_persqueue TO jsuser;
GRANT DELETE ON jsuser.js_persqueue TO jsuser;

GRANT SELECT ON jsuser.js_opstatus TO jsuser;
GRANT UPDATE ON jsuser.js_opstatus TO jsuser;
GRANT INSERT ON jsuser.js_opstatus TO jsuser;
GRANT DELETE ON jsuser.js_opstatus TO jsuser;

GRANT SELECT ON jsuser.js_wbstatus TO jsuser;
GRANT UPDATE ON jsuser.js_wbstatus TO jsuser;
GRANT INSERT ON jsuser.js_wbstatus TO jsuser;
GRANT DELETE ON jsuser.js_wbstatus TO jsuser;

GRANT SELECT ON jsuser.js_engstatus TO jsuser;
GRANT UPDATE ON jsuser.js_engstatus TO jsuser;
GRANT INSERT ON jsuser.js_engstatus TO jsuser;
GRANT DELETE ON jsuser.js_engstatus TO jsuser;

GRANT SELECT ON jsuser.js_runwbstate TO jsuser;
GRANT UPDATE ON jsuser.js_runwbstate TO jsuser;
GRANT INSERT ON jsuser.js_runwbstate TO jsuser;
GRANT DELETE ON jsuser.js_runwbstate TO jsuser;

GRANT SELECT ON jsuser.js_runwbdata TO jsuser;
GRANT UPDATE ON jsuser.js_runwbdata TO jsuser;
GRANT INSERT ON jsuser.js_runwbdata TO jsuser;
GRANT DELETE ON jsuser.js_runwbdata TO jsuser;

GRANT SELECT ON jsuser.js_juser TO jsuser;
GRANT UPDATE ON jsuser.js_juser TO jsuser;
GRANT INSERT ON jsuser.js_juser TO jsuser;
GRANT DELETE ON jsuser.js_juser TO jsuser;

GRANT SELECT ON jsuser.js_jobgroup TO jsuser;
GRANT UPDATE ON jsuser.js_jobgroup TO jsuser;
GRANT INSERT ON jsuser.js_jobgroup TO jsuser;
GRANT DELETE ON jsuser.js_jobgroup TO jsuser;

GRANT SELECT ON jsuser.js_user_region TO jsuser;
GRANT UPDATE ON jsuser.js_user_region TO jsuser;
GRANT INSERT ON jsuser.js_user_region TO jsuser;
GRANT DELETE ON jsuser.js_user_region TO jsuser;

GRANT SELECT ON jsuser.js_user_jobgroup TO jsuser;
GRANT UPDATE ON jsuser.js_user_jobgroup TO jsuser;
GRANT INSERT ON jsuser.js_user_jobgroup TO jsuser;
GRANT DELETE ON jsuser.js_user_jobgroup TO jsuser;

GRANT SELECT ON jsuser.js_user_partition TO jsuser;
GRANT UPDATE ON jsuser.js_user_partition TO jsuser;
GRANT INSERT ON jsuser.js_user_partition TO jsuser;
GRANT DELETE ON jsuser.js_user_partition TO jsuser;

GRANT SELECT ON jsuser.js_depend TO jsuser;
GRANT UPDATE ON jsuser.js_depend TO jsuser;
GRANT INSERT ON jsuser.js_depend TO jsuser;
GRANT DELETE ON jsuser.js_depend TO jsuser;

GRANT SELECT ON jsuser.js_taudit TO jsuser;
GRANT UPDATE ON jsuser.js_taudit TO jsuser;
GRANT INSERT ON jsuser.js_taudit TO jsuser;
GRANT DELETE ON jsuser.js_taudit TO jsuser;

GRANT SELECT ON jsuser.js_lock_tbl TO jsuser;
GRANT UPDATE ON jsuser.js_lock_tbl TO jsuser;
GRANT INSERT ON jsuser.js_lock_tbl TO jsuser;
GRANT DELETE ON jsuser.js_lock_tbl TO jsuser;

GRANT SELECT ON jsuser.js_syscheck TO jsuser;
GRANT UPDATE ON jsuser.js_syscheck TO jsuser;
GRANT INSERT ON jsuser.js_syscheck TO jsuser;
GRANT DELETE ON jsuser.js_syscheck TO jsuser;

GRANT SELECT ON jsuser.js_node_partition_rel TO jsuser;
GRANT UPDATE ON jsuser.js_node_partition_rel TO jsuser;
GRANT INSERT ON jsuser.js_node_partition_rel TO jsuser;
GRANT DELETE ON jsuser.js_node_partition_rel TO jsuser;

GRANT SELECT ON jsuser.js_node TO jsuser;
GRANT UPDATE ON jsuser.js_node TO jsuser;
GRANT INSERT ON jsuser.js_node TO jsuser;
GRANT DELETE ON jsuser.js_node TO jsuser;

GRANT SELECT ON jsuser.js_nodestatus TO jsuser;
GRANT UPDATE ON jsuser.js_nodestatus TO jsuser;
GRANT INSERT ON jsuser.js_nodestatus TO jsuser;
GRANT DELETE ON jsuser.js_nodestatus TO jsuser;

GRANT SELECT ON jsuser.js_systeminfo TO jsuser;
GRANT UPDATE ON jsuser.js_systeminfo TO jsuser;
GRANT INSERT ON jsuser.js_systeminfo TO jsuser;
GRANT DELETE ON jsuser.js_systeminfo TO jsuser

*/
