/*
 * To change this template, choose Tools | Templates
 * and open the template in the editor.
 */

package org.soafaces.bundle.client.rpc;

import com.google.gwt.user.client.rpc.IsSerializable;
import java.util.Date;

/**
 * Container class that holds various properties associated with a Tasklet/job.
 *
 * @author Sam Taha
 */
public interface TaskletStatus extends IsSerializable {

  /**
   * <p>
   * <code>APP_SCOPE</code> are cookies that are shared between all jobs runs and during job editing. These cookies
   * can be set/get by Tasklet manual editing or during a job run.
   *</p>
   * <p>
   * <code>RUN_SCOPE</code> are cookies that are available only while the job is running and between retries of a job run.
   * </p>
   */
  public enum Scope
  {
    APP_SCOPE,
    RUN_SCOPE
  };

  /**
   *  When Tasklet started running.
   *
   * @return null if Tasklet has not started.
   */
  public Date getStartTime();

  /**
   * Date when Tasklets finished running.
   *
   * @return null if Tasklet is not finished running or terminated abruptly.
   */
  public Date getEndTime();
  /**
   * Tasklet defined custom status code. Shows the final status code from the
   * Tasklet that ran earlier in the workflow chain.
   *
   * @return null by default, unless the tasklet defines a custom status code.
   */
  public Integer getCustomStatusCode();

  /**
   * Tasklet defined custom status message. Shows the final status message from the
   * Tasklet that ran earlier in the workflow chain.
   *
   * @return Empty String by default, unless the tasklet defines a custom status message.
   */
  public String getCustomStatusMessage();

  /**
   * <p>
   * Cookies are Tasklet properties that are set by a Tasklet as it runs and made available
   * for viewing by a Tasklets GUIs (RuntimeViewer). This method returns both APP
   * scope and RUN scope cookies.
   * </p>
   *
   * The cookie properties are available to the RuntimeViewer GWT GUIs that are associated
   * to a Tasklet. This allows developers to
   * customize GWT GUIs to monitor progress and status reported by the Tasklet as the
   * Tasklet runs. See <code>IOViewerContext.fetchTaskletStatus()</code> for how to
   * request cookies and other Tasklet related properties from your RuntimeViewer GWT client.
   *
   * <p>
   * If you need to send complex table or array data to the RuntimeViewer, it is recommended you send this
   * as a serialized JSON string. This can then be parsed more efficiently by the GWT
   * RuntimeViewer to display the status details in the GUI.
   * </p>
   *
   * @param name
   *
   * @return The Tasklet may save JSON string. It is up to the RuntimeViewer to parse this.
   */
  public String getCookie(String name, Scope scope);
  
}
