package org.soafaces.bundle.client.rpc.impl;

import com.google.gwt.user.client.rpc.IsSerializable;
import java.util.HashMap;
import java.util.Map;
import org.soafaces.bundle.client.rpc.AppCookie;

/**
 * This is a container for name/value proeprties that are avaialble to a Weblet and/or Tasklet.
 * If used with Tasklets, these properties are shared between all the job runs
 * of a Tasklet. 
 *
 * @author Sam Taha
 */
public class AppCookieImpl implements AppCookie, IsSerializable {

  private Map<String,String> appCookieMap=null;
  private Map<String,String> editCookieMap=null;

  private AppCookieImpl() {}
  public AppCookieImpl(Map<String,String> appCookieMap)
  {
    this.appCookieMap=appCookieMap;
  }

  /**
   * <p>
   * Cookies are Tasklet/Weblet properties that can used by a Tasklet as it runs.
   * This method returns only APP_SCOPE
   * cookie properties. APP_SCOPE cookies are name/value properties available at the
   * job and the application level. They are shared between all job runs and by the
   * Weblet/RuntimeViewer GUI interfaces associated with a Tasklet.
   * </p>
   *
   * <p>
   * For example, as a Tasklet runs in a job, cookies can be set and read and shared
   * between other runnning jobs/Tasklets. Also, cookies can be edited manually using
   * the Weblet GUI so that they can later be read by a Tasklet as it runs.
   * </>
   *
   * @param name
   *
   * @return The Tasklet may save JSON string. It is up to the RuntimeViewer to parse this.
   */
  public String getCookie(String name)
  {
    if(appCookieMap == null)
      return null;

    return appCookieMap.get(name);
  }

  public void setCookie(String name, String value)
  {
    if(editCookieMap == null)
      editCookieMap=new HashMap();

    editCookieMap.put(name, value);
  }

  public void clearEditCookies()
  {
    if(editCookieMap != null)
      editCookieMap.clear();
  }

  Map<String, String> getEditCookieMap()
  {
    return editCookieMap;
  }
}
